==> huaweicloudsdkvpc-3.1.80-py2.py3-none-any.whl: huaweicloudsdkvpc/v3/model/firewall_remove_rule_option.py <==
# coding: utf-8

import six

from huaweicloudsdkcore.utils.http_utils import sanitize_for_serialization


class FirewallRemoveRuleOption:

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    sensitive_list = []

    openapi_types = {
        'ingress_rules': 'list[FirewallRemoveRuleItemOption]',
        'egress_rules': 'list[FirewallRemoveRuleItemOption]'
    }

    attribute_map = {
        'ingress_rules': 'ingress_rules',
        'egress_rules': 'egress_rules'
    }

    def __init__(self, ingress_rules=None, egress_rules=None):
        """FirewallRemoveRuleOption

        The model defined in huaweicloud sdk

        :param ingress_rules: 功能说明：ACL删除入方向规则列表 约束：ingress_rules和egress_rules仅能同时设置一个
        :type ingress_rules: list[:class:`huaweicloudsdkvpc.v3.FirewallRemoveRuleItemOption`]
        :param egress_rules: 功能说明：ACL删除出方向规则列表 约束：ingress_rules和egress_rules仅能同时设置一个
        :type egress_rules: list[:class:`huaweicloudsdkvpc.v3.FirewallRemoveRuleItemOption`]
        """
        
        

        self._ingress_rules = None
        self._egress_rules = None
        self.discriminator = None

        if ingress_rules is not None:
            self.ingress_rules = ingress_rules
        if egress_rules is not None:
            self.egress_rules = egress_rules

    @property
    def ingress_rules(self):
        """Gets the ingress_rules of this FirewallRemoveRuleOption.

        功能说明：ACL删除入方向规则列表 约束：ingress_rules和egress_rules仅能同时设置一个

        :return: The ingress_rules of this FirewallRemoveRuleOption.
        :rtype: list[:class:`huaweicloudsdkvpc.v3.FirewallRemoveRuleItemOption`]
        """
        return self._ingress_rules

    @ingress_rules.setter
    def ingress_rules(self, ingress_rules):
        """Sets the ingress_rules of this FirewallRemoveRuleOption.

        功能说明：ACL删除入方向规则列表 约束：ingress_rules和egress_rules仅能同时设置一个

        :param ingress_rules: The ingress_rules of this FirewallRemoveRuleOption.
        :type ingress_rules: list[:class:`huaweicloudsdkvpc.v3.FirewallRemoveRuleItemOption`]
        """
        self._ingress_rules = ingress_rules

    @property
    def egress_rules(self):
        """Gets the egress_rules of this FirewallRemoveRuleOption.

        功能说明：ACL删除出方向规则列表 约束：ingress_rules和egress_rules仅能同时设置一个

        :return: The egress_rules of this FirewallRemoveRuleOption.
        :rtype: list[:class:`huaweicloudsdkvpc.v3.FirewallRemoveRuleItemOption`]
        """
        return self._egress_rules

    @egress_rules.setter
    def egress_rules(self, egress_rules):
        """Sets the egress_rules of this FirewallRemoveRuleOption.

        功能说明：ACL删除出方向规则列表 约束：ingress_rules和egress_rules仅能同时设置一个

        :param egress_rules: The egress_rules of this FirewallRemoveRuleOption.
        :type egress_rules: list[:class:`huaweicloudsdkvpc.v3.FirewallRemoveRuleItemOption`]
        """
        self._egress_rules = egress_rules

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                if attr in self.sensitive_list:
                    result[attr] = "****"
                else:
                    result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        import simplejson as json
        if six.PY2:
            import sys
            reload(sys)
            sys.setdefaultencoding("utf-8")
        return json.dumps(sanitize_for_serialization(self), ensure_ascii=False)

    def __repr__(self):
        """For `print`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, FirewallRemoveRuleOption):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other

==> huaweicloudsdkvpc-3.1.150-py2.py3-none-any.whl: huaweicloudsdkvpc/v3/model/firewall_remove_rule_option.py <==
# coding: utf-8

import six

from huaweicloudsdkcore.utils.http_utils import sanitize_for_serialization


class FirewallRemoveRuleOption:

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    sensitive_list = []

    openapi_types = {
        'ingress_rules': 'list[FirewallRemoveRuleItemOption]',
        'egress_rules': 'list[FirewallRemoveRuleItemOption]'
    }

    attribute_map = {
        'ingress_rules': 'ingress_rules',
        'egress_rules': 'egress_rules'
    }

    def __init__(self, ingress_rules=None, egress_rules=None):
        r"""FirewallRemoveRuleOption

        The model defined in huaweicloud sdk

        :param ingress_rules: 功能说明：ACL删除入方向规则列表 约束：ingress_rules和egress_rules仅能同时设置一个
        :type ingress_rules: list[:class:`huaweicloudsdkvpc.v3.FirewallRemoveRuleItemOption`]
        :param egress_rules: 功能说明：ACL删除出方向规则列表 约束：ingress_rules和egress_rules仅能同时设置一个
        :type egress_rules: list[:class:`huaweicloudsdkvpc.v3.FirewallRemoveRuleItemOption`]
        """
        
        

        self._ingress_rules = None
        self._egress_rules = None
        self.discriminator = None

        if ingress_rules is not None:
            self.ingress_rules = ingress_rules
        if egress_rules is not None:
            self.egress_rules = egress_rules

    @property
    def ingress_rules(self):
        r"""Gets the ingress_rules of this FirewallRemoveRuleOption.

        功能说明：ACL删除入方向规则列表 约束：ingress_rules和egress_rules仅能同时设置一个

        :return: The ingress_rules of this FirewallRemoveRuleOption.
        :rtype: list[:class:`huaweicloudsdkvpc.v3.FirewallRemoveRuleItemOption`]
        """
        return self._ingress_rules

    @ingress_rules.setter
    def ingress_rules(self, ingress_rules):
        r"""Sets the ingress_rules of this FirewallRemoveRuleOption.

        功能说明：ACL删除入方向规则列表 约束：ingress_rules和egress_rules仅能同时设置一个

        :param ingress_rules: The ingress_rules of this FirewallRemoveRuleOption.
        :type ingress_rules: list[:class:`huaweicloudsdkvpc.v3.FirewallRemoveRuleItemOption`]
        """
        self._ingress_rules = ingress_rules

    @property
    def egress_rules(self):
        r"""Gets the egress_rules of this FirewallRemoveRuleOption.

        功能说明：ACL删除出方向规则列表 约束：ingress_rules和egress_rules仅能同时设置一个

        :return: The egress_rules of this FirewallRemoveRuleOption.
        :rtype: list[:class:`huaweicloudsdkvpc.v3.FirewallRemoveRuleItemOption`]
        """
        return self._egress_rules

    @egress_rules.setter
    def egress_rules(self, egress_rules):
        r"""Sets the egress_rules of this FirewallRemoveRuleOption.

        功能说明：ACL删除出方向规则列表 约束：ingress_rules和egress_rules仅能同时设置一个

        :param egress_rules: The egress_rules of this FirewallRemoveRuleOption.
        :type egress_rules: list[:class:`huaweicloudsdkvpc.v3.FirewallRemoveRuleItemOption`]
        """
        self._egress_rules = egress_rules

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                if attr in self.sensitive_list:
                    result[attr] = "****"
                else:
                    result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        import simplejson as json
        if six.PY2:
            import sys
            reload(sys)
            sys.setdefaultencoding("utf-8")
        return json.dumps(sanitize_for_serialization(self), ensure_ascii=False)

    def __repr__(self):
        """For `print`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, FirewallRemoveRuleOption):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other
